/**
 * List of supported Papirus theme variants.
 */
export const PapirusThemes = ['Papirus', 'Papirus-Dark', 'Papirus-Light'];

/**
 * Mapping from GNOME accent colors to Papirus folder colors.
 */
export const AccentToPapirus = {
    blue: 'adwaita',
    teal: 'darkcyan',
    green: 'green',
    yellow: 'yellow',
    orange: 'deeporange',
    red: 'red',
    pink: 'pink',
    purple: 'magenta',
    slate: 'bluegrey',
    maia: 'teal',
};
